@@ -2,7 +2,7 @@ use crate::FallibleStreamingIterator;
 
 /// [`DynIter`] is an implementation of a single-threaded, dynamically-typed iterator.
 pub struct DynIter<'a, V> {
-    iter: Box<dyn Iterator<Item = V> + 'a>,
+    iter: Box<dyn Iterator<Item = V> + 'a + Send + Sync>,
 }
 
 impl<'a, V> Iterator for DynIter<'a, V> {
@@ -19,7 +19,7 @@ impl<'a, V> Iterator for DynIter<'a, V> {
 impl<'a, V> DynIter<'a, V> {
     pub fn new<I>(iter: I) -> Self
     where
-        I: Iterator<Item = V> + 'a,
+        I: Iterator<Item = V> + 'a + Send + Sync,
     {
         Self {
             iter: Box::new(iter),
@@ -29,7 +29,7 @@ impl<'a, V> DynIter<'a, V> {
 
 /// Dynamically-typed [`FallibleStreamingIterator`].
 pub struct DynStreamingIterator<'a, V, E> {
-    iter: Box<dyn FallibleStreamingIterator<Item = V, Error = E> + 'a>,
+    iter: Box<dyn FallibleStreamingIterator<Item = V, Error = E> + 'a + Send + Sync>,
 }
 
 impl<'a, V, E> FallibleStreamingIterator for DynStreamingIterator<'a, V, E> {
@@ -52,7 +52,7 @@ impl<'a, V, E> FallibleStreamingIterator for DynStreamingIterator<'a, V, E> {
 impl<'a, V, E> DynStreamingIterator<'a, V, E> {
     pub fn new<I>(iter: I) -> Self
     where
-        I: FallibleStreamingIterator<Item = V, Error = E> + 'a,
+        I: FallibleStreamingIterator<Item = V, Error = E> + 'a + Send + Sync,
     {
         Self {
             iter: Box::new(iter),
